@@ -70,6 +70,8 @@ product_map = {
     118: "LIFX Z Intl",
     119: "LIFX Beam US",
     120: "LIFX Beam Intl",
+    121: "LIFX Downlight Intl",
+    122: "LIFX Downlight US",
     123: "LIFX Color US",
     124: "LIFX Color Intl",
     125: "LIFX White to Warm US",
@@ -1011,6 +1013,32 @@ features_map = {
         "multizone": True,
         "relays": False,
     },
+    121: {
+        "buttons": False,
+        "chain": False,
+        "color": True,
+        "extended_multizone": False,
+        "hev": False,
+        "infrared": False,
+        "matrix": False,
+        "max_kelvin": 9000,
+        "min_kelvin": 1500,
+        "multizone": False,
+        "relays": False,
+    },
+    122: {
+        "buttons": False,
+        "chain": False,
+        "color": True,
+        "extended_multizone": False,
+        "hev": False,
+        "infrared": False,
+        "matrix": False,
+        "max_kelvin": 9000,
+        "min_kelvin": 1500,
+        "multizone": False,
+        "relays": False,
+    },
     123: {
         "buttons": False,
         "chain": False,
